@@ -1,4 +1,4 @@
-# Copyright (c) 2019 - 2021, Adrian Dusa
+# Copyright (c) 2019 - 2022, Adrian Dusa
 # All rights reserved.
 # 
 # Redistribution and use in source and binary forms, with or without
@@ -24,7 +24,7 @@
 # SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 
 `reload` <- function(package, silent = TRUE) {
-    package <- recreate(substitute(package))
+    package <- as.character(substitute(package))
     unload(package)
     if (is.element(package, rownames(installed.packages()))) { 
         if (silent) {
